# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: access.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biostarPython.service import err_pb2 as err__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='access.proto',
  package='access',
  syntax='proto3',
  serialized_options=_b('\n\031com.supremainc.sdk.accessP\001Z\026biostar/service/access'),
  serialized_pb=_b('\n\x0c\x61\x63\x63\x65ss.proto\x12\x06\x61\x63\x63\x65ss\x1a\terr.proto\"\"\n\x0eGetListRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"9\n\x0b\x41\x63\x63\x65ssGroup\x12\n\n\x02ID\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08levelIDs\x18\x03 \x03(\r\"6\n\x0fGetListResponse\x12#\n\x06groups\x18\x01 \x03(\x0b\x32\x13.access.AccessGroup\"C\n\nAddRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12#\n\x06groups\x18\x02 \x03(\x0b\x32\x13.access.AccessGroup\"\r\n\x0b\x41\x64\x64Response\"I\n\x0f\x41\x64\x64MultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12#\n\x06groups\x18\x02 \x03(\x0b\x32\x13.access.AccessGroup\"<\n\x10\x41\x64\x64MultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\"3\n\rDeleteRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\x10\n\x08groupIDs\x18\x02 \x03(\r\"\x10\n\x0e\x44\x65leteResponse\"9\n\x12\x44\x65leteMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12\x10\n\x08groupIDs\x18\x02 \x03(\r\"?\n\x13\x44\x65leteMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\"$\n\x10\x44\x65leteAllRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"\x13\n\x11\x44\x65leteAllResponse\"*\n\x15\x44\x65leteAllMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\"B\n\x16\x44\x65leteAllMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\"\'\n\x13GetLevelListRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"2\n\x0c\x44oorSchedule\x12\x0e\n\x06\x64oorID\x18\x01 \x01(\r\x12\x12\n\nscheduleID\x18\x02 \x01(\r\"T\n\x0b\x41\x63\x63\x65ssLevel\x12\n\n\x02ID\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12+\n\rdoorSchedules\x18\x03 \x03(\x0b\x32\x14.access.DoorSchedule\";\n\x14GetLevelListResponse\x12#\n\x06levels\x18\x01 \x03(\x0b\x32\x13.access.AccessLevel\"H\n\x0f\x41\x64\x64LevelRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12#\n\x06levels\x18\x02 \x03(\x0b\x32\x13.access.AccessLevel\"\x12\n\x10\x41\x64\x64LevelResponse\"N\n\x14\x41\x64\x64LevelMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12#\n\x06levels\x18\x02 \x03(\x0b\x32\x13.access.AccessLevel\"A\n\x15\x41\x64\x64LevelMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\"8\n\x12\x44\x65leteLevelRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\x10\n\x08levelIDs\x18\x02 \x03(\r\"\x15\n\x13\x44\x65leteLevelResponse\">\n\x17\x44\x65leteLevelMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12\x10\n\x08levelIDs\x18\x02 \x03(\r\"D\n\x18\x44\x65leteLevelMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\")\n\x15\x44\x65leteAllLevelRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"\x18\n\x16\x44\x65leteAllLevelResponse\"/\n\x1a\x44\x65leteAllLevelMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\"G\n\x1b\x44\x65leteAllLevelMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\"G\n\rFloorSchedule\x12\x0e\n\x06liftID\x18\x01 \x01(\r\x12\x12\n\nfloorIndex\x18\x02 \x01(\r\x12\x12\n\nscheduleID\x18\x03 \x01(\r\"U\n\nFloorLevel\x12\n\n\x02ID\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12-\n\x0e\x66loorSchedules\x18\x03 \x03(\x0b\x32\x15.access.FloorSchedule\",\n\x18GetFloorLevelListRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"?\n\x19GetFloorLevelListResponse\x12\"\n\x06levels\x18\x01 \x03(\x0b\x32\x12.access.FloorLevel\"L\n\x14\x41\x64\x64\x46loorLevelRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\"\n\x06levels\x18\x02 \x03(\x0b\x32\x12.access.FloorLevel\"\x17\n\x15\x41\x64\x64\x46loorLevelResponse\"R\n\x19\x41\x64\x64\x46loorLevelMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12\"\n\x06levels\x18\x02 \x03(\x0b\x32\x12.access.FloorLevel\"F\n\x1a\x41\x64\x64\x46loorLevelMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\"=\n\x17\x44\x65leteFloorLevelRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\x10\n\x08levelIDs\x18\x02 \x03(\r\"\x1a\n\x18\x44\x65leteFloorLevelResponse\"C\n\x1c\x44\x65leteFloorLevelMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12\x10\n\x08levelIDs\x18\x02 \x03(\r\"I\n\x1d\x44\x65leteFloorLevelMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\".\n\x1a\x44\x65leteAllFloorLevelRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"\x1d\n\x1b\x44\x65leteAllFloorLevelResponse\"4\n\x1f\x44\x65leteAllFloorLevelMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\"L\n DeleteAllFloorLevelMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse2\x80\r\n\x06\x41\x63\x63\x65ss\x12:\n\x07GetList\x12\x16.access.GetListRequest\x1a\x17.access.GetListResponse\x12.\n\x03\x41\x64\x64\x12\x12.access.AddRequest\x1a\x13.access.AddResponse\x12=\n\x08\x41\x64\x64Multi\x12\x17.access.AddMultiRequest\x1a\x18.access.AddMultiResponse\x12\x37\n\x06\x44\x65lete\x12\x15.access.DeleteRequest\x1a\x16.access.DeleteResponse\x12\x46\n\x0b\x44\x65leteMulti\x12\x1a.access.DeleteMultiRequest\x1a\x1b.access.DeleteMultiResponse\x12@\n\tDeleteAll\x12\x18.access.DeleteAllRequest\x1a\x19.access.DeleteAllResponse\x12O\n\x0e\x44\x65leteAllMulti\x12\x1d.access.DeleteAllMultiRequest\x1a\x1e.access.DeleteAllMultiResponse\x12I\n\x0cGetLevelList\x12\x1b.access.GetLevelListRequest\x1a\x1c.access.GetLevelListResponse\x12=\n\x08\x41\x64\x64Level\x12\x17.access.AddLevelRequest\x1a\x18.access.AddLevelResponse\x12L\n\rAddLevelMulti\x12\x1c.access.AddLevelMultiRequest\x1a\x1d.access.AddLevelMultiResponse\x12\x46\n\x0b\x44\x65leteLevel\x12\x1a.access.DeleteLevelRequest\x1a\x1b.access.DeleteLevelResponse\x12U\n\x10\x44\x65leteLevelMulti\x12\x1f.access.DeleteLevelMultiRequest\x1a .access.DeleteLevelMultiResponse\x12O\n\x0e\x44\x65leteAllLevel\x12\x1d.access.DeleteAllLevelRequest\x1a\x1e.access.DeleteAllLevelResponse\x12^\n\x13\x44\x65leteAllLevelMulti\x12\".access.DeleteAllLevelMultiRequest\x1a#.access.DeleteAllLevelMultiResponse\x12X\n\x11GetFloorLevelList\x12 .access.GetFloorLevelListRequest\x1a!.access.GetFloorLevelListResponse\x12L\n\rAddFloorLevel\x12\x1c.access.AddFloorLevelRequest\x1a\x1d.access.AddFloorLevelResponse\x12[\n\x12\x41\x64\x64\x46loorLevelMulti\x12!.access.AddFloorLevelMultiRequest\x1a\".access.AddFloorLevelMultiResponse\x12U\n\x10\x44\x65leteFloorLevel\x12\x1f.access.DeleteFloorLevelRequest\x1a .access.DeleteFloorLevelResponse\x12\x64\n\x15\x44\x65leteFloorLevelMulti\x12$.access.DeleteFloorLevelMultiRequest\x1a%.access.DeleteFloorLevelMultiResponse\x12^\n\x13\x44\x65leteAllFloorLevel\x12\".access.DeleteAllFloorLevelRequest\x1a#.access.DeleteAllFloorLevelResponse\x12m\n\x18\x44\x65leteAllFloorLevelMulti\x12\'.access.DeleteAllFloorLevelMultiRequest\x1a(.access.DeleteAllFloorLevelMultiResponseB5\n\x19\x63om.supremainc.sdk.accessP\x01Z\x16\x62iostar/service/accessb\x06proto3')
  ,
  dependencies=[err__pb2.DESCRIPTOR,])




_GETLISTREQUEST = _descriptor.Descriptor(
  name='GetListRequest',
  full_name='access.GetListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='access.GetListRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=35,
  serialized_end=69,
)


_ACCESSGROUP = _descriptor.Descriptor(
  name='AccessGroup',
  full_name='access.AccessGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ID', full_name='access.AccessGroup.ID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='access.AccessGroup.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='levelIDs', full_name='access.AccessGroup.levelIDs', index=2,
      number=3, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=71,
  serialized_end=128,
)


_GETLISTRESPONSE = _descriptor.Descriptor(
  name='GetListResponse',
  full_name='access.GetListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='groups', full_name='access.GetListResponse.groups', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=130,
  serialized_end=184,
)


_ADDREQUEST = _descriptor.Descriptor(
  name='AddRequest',
  full_name='access.AddRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='access.AddRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='groups', full_name='access.AddRequest.groups', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=186,
  serialized_end=253,
)


_ADDRESPONSE = _descriptor.Descriptor(
  name='AddResponse',
  full_name='access.AddResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=255,
  serialized_end=268,
)


_ADDMULTIREQUEST = _descriptor.Descriptor(
  name='AddMultiRequest',
  full_name='access.AddMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='access.AddMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='groups', full_name='access.AddMultiRequest.groups', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=270,
  serialized_end=343,
)


_ADDMULTIRESPONSE = _descriptor.Descriptor(
  name='AddMultiResponse',
  full_name='access.AddMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='access.AddMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=345,
  serialized_end=405,
)


_DELETEREQUEST = _descriptor.Descriptor(
  name='DeleteRequest',
  full_name='access.DeleteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='access.DeleteRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='groupIDs', full_name='access.DeleteRequest.groupIDs', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=407,
  serialized_end=458,
)


_DELETERESPONSE = _descriptor.Descriptor(
  name='DeleteResponse',
  full_name='access.DeleteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=460,
  serialized_end=476,
)


_DELETEMULTIREQUEST = _descriptor.Descriptor(
  name='DeleteMultiRequest',
  full_name='access.DeleteMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='access.DeleteMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='groupIDs', full_name='access.DeleteMultiRequest.groupIDs', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=478,
  serialized_end=535,
)


_DELETEMULTIRESPONSE = _descriptor.Descriptor(
  name='DeleteMultiResponse',
  full_name='access.DeleteMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='access.DeleteMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=537,
  serialized_end=600,
)


_DELETEALLREQUEST = _descriptor.Descriptor(
  name='DeleteAllRequest',
  full_name='access.DeleteAllRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='access.DeleteAllRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=602,
  serialized_end=638,
)


_DELETEALLRESPONSE = _descriptor.Descriptor(
  name='DeleteAllResponse',
  full_name='access.DeleteAllResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=640,
  serialized_end=659,
)


_DELETEALLMULTIREQUEST = _descriptor.Descriptor(
  name='DeleteAllMultiRequest',
  full_name='access.DeleteAllMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='access.DeleteAllMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=661,
  serialized_end=703,
)


_DELETEALLMULTIRESPONSE = _descriptor.Descriptor(
  name='DeleteAllMultiResponse',
  full_name='access.DeleteAllMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='access.DeleteAllMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=705,
  serialized_end=771,
)


_GETLEVELLISTREQUEST = _descriptor.Descriptor(
  name='GetLevelListRequest',
  full_name='access.GetLevelListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='access.GetLevelListRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=773,
  serialized_end=812,
)


_DOORSCHEDULE = _descriptor.Descriptor(
  name='DoorSchedule',
  full_name='access.DoorSchedule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='doorID', full_name='access.DoorSchedule.doorID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scheduleID', full_name='access.DoorSchedule.scheduleID', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=814,
  serialized_end=864,
)


_ACCESSLEVEL = _descriptor.Descriptor(
  name='AccessLevel',
  full_name='access.AccessLevel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ID', full_name='access.AccessLevel.ID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='access.AccessLevel.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='doorSchedules', full_name='access.AccessLevel.doorSchedules', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=866,
  serialized_end=950,
)


_GETLEVELLISTRESPONSE = _descriptor.Descriptor(
  name='GetLevelListResponse',
  full_name='access.GetLevelListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='levels', full_name='access.GetLevelListResponse.levels', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=952,
  serialized_end=1011,
)


_ADDLEVELREQUEST = _descriptor.Descriptor(
  name='AddLevelRequest',
  full_name='access.AddLevelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='access.AddLevelRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='levels', full_name='access.AddLevelRequest.levels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1013,
  serialized_end=1085,
)


_ADDLEVELRESPONSE = _descriptor.Descriptor(
  name='AddLevelResponse',
  full_name='access.AddLevelResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1087,
  serialized_end=1105,
)


_ADDLEVELMULTIREQUEST = _descriptor.Descriptor(
  name='AddLevelMultiRequest',
  full_name='access.AddLevelMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='access.AddLevelMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='levels', full_name='access.AddLevelMultiRequest.levels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1107,
  serialized_end=1185,
)


_ADDLEVELMULTIRESPONSE = _descriptor.Descriptor(
  name='AddLevelMultiResponse',
  full_name='access.AddLevelMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='access.AddLevelMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1187,
  serialized_end=1252,
)


_DELETELEVELREQUEST = _descriptor.Descriptor(
  name='DeleteLevelRequest',
  full_name='access.DeleteLevelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='access.DeleteLevelRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='levelIDs', full_name='access.DeleteLevelRequest.levelIDs', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1254,
  serialized_end=1310,
)


_DELETELEVELRESPONSE = _descriptor.Descriptor(
  name='DeleteLevelResponse',
  full_name='access.DeleteLevelResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1312,
  serialized_end=1333,
)


_DELETELEVELMULTIREQUEST = _descriptor.Descriptor(
  name='DeleteLevelMultiRequest',
  full_name='access.DeleteLevelMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='access.DeleteLevelMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='levelIDs', full_name='access.DeleteLevelMultiRequest.levelIDs', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1335,
  serialized_end=1397,
)


_DELETELEVELMULTIRESPONSE = _descriptor.Descriptor(
  name='DeleteLevelMultiResponse',
  full_name='access.DeleteLevelMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='access.DeleteLevelMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1399,
  serialized_end=1467,
)


_DELETEALLLEVELREQUEST = _descriptor.Descriptor(
  name='DeleteAllLevelRequest',
  full_name='access.DeleteAllLevelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='access.DeleteAllLevelRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1469,
  serialized_end=1510,
)


_DELETEALLLEVELRESPONSE = _descriptor.Descriptor(
  name='DeleteAllLevelResponse',
  full_name='access.DeleteAllLevelResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1512,
  serialized_end=1536,
)


_DELETEALLLEVELMULTIREQUEST = _descriptor.Descriptor(
  name='DeleteAllLevelMultiRequest',
  full_name='access.DeleteAllLevelMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='access.DeleteAllLevelMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1538,
  serialized_end=1585,
)


_DELETEALLLEVELMULTIRESPONSE = _descriptor.Descriptor(
  name='DeleteAllLevelMultiResponse',
  full_name='access.DeleteAllLevelMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='access.DeleteAllLevelMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1587,
  serialized_end=1658,
)


_FLOORSCHEDULE = _descriptor.Descriptor(
  name='FloorSchedule',
  full_name='access.FloorSchedule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='liftID', full_name='access.FloorSchedule.liftID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='floorIndex', full_name='access.FloorSchedule.floorIndex', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scheduleID', full_name='access.FloorSchedule.scheduleID', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1660,
  serialized_end=1731,
)


_FLOORLEVEL = _descriptor.Descriptor(
  name='FloorLevel',
  full_name='access.FloorLevel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ID', full_name='access.FloorLevel.ID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='access.FloorLevel.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='floorSchedules', full_name='access.FloorLevel.floorSchedules', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1733,
  serialized_end=1818,
)


_GETFLOORLEVELLISTREQUEST = _descriptor.Descriptor(
  name='GetFloorLevelListRequest',
  full_name='access.GetFloorLevelListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='access.GetFloorLevelListRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1820,
  serialized_end=1864,
)


_GETFLOORLEVELLISTRESPONSE = _descriptor.Descriptor(
  name='GetFloorLevelListResponse',
  full_name='access.GetFloorLevelListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='levels', full_name='access.GetFloorLevelListResponse.levels', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1866,
  serialized_end=1929,
)


_ADDFLOORLEVELREQUEST = _descriptor.Descriptor(
  name='AddFloorLevelRequest',
  full_name='access.AddFloorLevelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='access.AddFloorLevelRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='levels', full_name='access.AddFloorLevelRequest.levels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1931,
  serialized_end=2007,
)


_ADDFLOORLEVELRESPONSE = _descriptor.Descriptor(
  name='AddFloorLevelResponse',
  full_name='access.AddFloorLevelResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2009,
  serialized_end=2032,
)


_ADDFLOORLEVELMULTIREQUEST = _descriptor.Descriptor(
  name='AddFloorLevelMultiRequest',
  full_name='access.AddFloorLevelMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='access.AddFloorLevelMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='levels', full_name='access.AddFloorLevelMultiRequest.levels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2034,
  serialized_end=2116,
)


_ADDFLOORLEVELMULTIRESPONSE = _descriptor.Descriptor(
  name='AddFloorLevelMultiResponse',
  full_name='access.AddFloorLevelMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='access.AddFloorLevelMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2118,
  serialized_end=2188,
)


_DELETEFLOORLEVELREQUEST = _descriptor.Descriptor(
  name='DeleteFloorLevelRequest',
  full_name='access.DeleteFloorLevelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='access.DeleteFloorLevelRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='levelIDs', full_name='access.DeleteFloorLevelRequest.levelIDs', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2190,
  serialized_end=2251,
)


_DELETEFLOORLEVELRESPONSE = _descriptor.Descriptor(
  name='DeleteFloorLevelResponse',
  full_name='access.DeleteFloorLevelResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2253,
  serialized_end=2279,
)


_DELETEFLOORLEVELMULTIREQUEST = _descriptor.Descriptor(
  name='DeleteFloorLevelMultiRequest',
  full_name='access.DeleteFloorLevelMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='access.DeleteFloorLevelMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='levelIDs', full_name='access.DeleteFloorLevelMultiRequest.levelIDs', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2281,
  serialized_end=2348,
)


_DELETEFLOORLEVELMULTIRESPONSE = _descriptor.Descriptor(
  name='DeleteFloorLevelMultiResponse',
  full_name='access.DeleteFloorLevelMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='access.DeleteFloorLevelMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2350,
  serialized_end=2423,
)


_DELETEALLFLOORLEVELREQUEST = _descriptor.Descriptor(
  name='DeleteAllFloorLevelRequest',
  full_name='access.DeleteAllFloorLevelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='access.DeleteAllFloorLevelRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2425,
  serialized_end=2471,
)


_DELETEALLFLOORLEVELRESPONSE = _descriptor.Descriptor(
  name='DeleteAllFloorLevelResponse',
  full_name='access.DeleteAllFloorLevelResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2473,
  serialized_end=2502,
)


_DELETEALLFLOORLEVELMULTIREQUEST = _descriptor.Descriptor(
  name='DeleteAllFloorLevelMultiRequest',
  full_name='access.DeleteAllFloorLevelMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='access.DeleteAllFloorLevelMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2504,
  serialized_end=2556,
)


_DELETEALLFLOORLEVELMULTIRESPONSE = _descriptor.Descriptor(
  name='DeleteAllFloorLevelMultiResponse',
  full_name='access.DeleteAllFloorLevelMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='access.DeleteAllFloorLevelMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2558,
  serialized_end=2634,
)

_GETLISTRESPONSE.fields_by_name['groups'].message_type = _ACCESSGROUP
_ADDREQUEST.fields_by_name['groups'].message_type = _ACCESSGROUP
_ADDMULTIREQUEST.fields_by_name['groups'].message_type = _ACCESSGROUP
_ADDMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
_DELETEMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
_DELETEALLMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
_ACCESSLEVEL.fields_by_name['doorSchedules'].message_type = _DOORSCHEDULE
_GETLEVELLISTRESPONSE.fields_by_name['levels'].message_type = _ACCESSLEVEL
_ADDLEVELREQUEST.fields_by_name['levels'].message_type = _ACCESSLEVEL
_ADDLEVELMULTIREQUEST.fields_by_name['levels'].message_type = _ACCESSLEVEL
_ADDLEVELMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
_DELETELEVELMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
_DELETEALLLEVELMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
_FLOORLEVEL.fields_by_name['floorSchedules'].message_type = _FLOORSCHEDULE
_GETFLOORLEVELLISTRESPONSE.fields_by_name['levels'].message_type = _FLOORLEVEL
_ADDFLOORLEVELREQUEST.fields_by_name['levels'].message_type = _FLOORLEVEL
_ADDFLOORLEVELMULTIREQUEST.fields_by_name['levels'].message_type = _FLOORLEVEL
_ADDFLOORLEVELMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
_DELETEFLOORLEVELMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
_DELETEALLFLOORLEVELMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
DESCRIPTOR.message_types_by_name['GetListRequest'] = _GETLISTREQUEST
DESCRIPTOR.message_types_by_name['AccessGroup'] = _ACCESSGROUP
DESCRIPTOR.message_types_by_name['GetListResponse'] = _GETLISTRESPONSE
DESCRIPTOR.message_types_by_name['AddRequest'] = _ADDREQUEST
DESCRIPTOR.message_types_by_name['AddResponse'] = _ADDRESPONSE
DESCRIPTOR.message_types_by_name['AddMultiRequest'] = _ADDMULTIREQUEST
DESCRIPTOR.message_types_by_name['AddMultiResponse'] = _ADDMULTIRESPONSE
DESCRIPTOR.message_types_by_name['DeleteRequest'] = _DELETEREQUEST
DESCRIPTOR.message_types_by_name['DeleteResponse'] = _DELETERESPONSE
DESCRIPTOR.message_types_by_name['DeleteMultiRequest'] = _DELETEMULTIREQUEST
DESCRIPTOR.message_types_by_name['DeleteMultiResponse'] = _DELETEMULTIRESPONSE
DESCRIPTOR.message_types_by_name['DeleteAllRequest'] = _DELETEALLREQUEST
DESCRIPTOR.message_types_by_name['DeleteAllResponse'] = _DELETEALLRESPONSE
DESCRIPTOR.message_types_by_name['DeleteAllMultiRequest'] = _DELETEALLMULTIREQUEST
DESCRIPTOR.message_types_by_name['DeleteAllMultiResponse'] = _DELETEALLMULTIRESPONSE
DESCRIPTOR.message_types_by_name['GetLevelListRequest'] = _GETLEVELLISTREQUEST
DESCRIPTOR.message_types_by_name['DoorSchedule'] = _DOORSCHEDULE
DESCRIPTOR.message_types_by_name['AccessLevel'] = _ACCESSLEVEL
DESCRIPTOR.message_types_by_name['GetLevelListResponse'] = _GETLEVELLISTRESPONSE
DESCRIPTOR.message_types_by_name['AddLevelRequest'] = _ADDLEVELREQUEST
DESCRIPTOR.message_types_by_name['AddLevelResponse'] = _ADDLEVELRESPONSE
DESCRIPTOR.message_types_by_name['AddLevelMultiRequest'] = _ADDLEVELMULTIREQUEST
DESCRIPTOR.message_types_by_name['AddLevelMultiResponse'] = _ADDLEVELMULTIRESPONSE
DESCRIPTOR.message_types_by_name['DeleteLevelRequest'] = _DELETELEVELREQUEST
DESCRIPTOR.message_types_by_name['DeleteLevelResponse'] = _DELETELEVELRESPONSE
DESCRIPTOR.message_types_by_name['DeleteLevelMultiRequest'] = _DELETELEVELMULTIREQUEST
DESCRIPTOR.message_types_by_name['DeleteLevelMultiResponse'] = _DELETELEVELMULTIRESPONSE
DESCRIPTOR.message_types_by_name['DeleteAllLevelRequest'] = _DELETEALLLEVELREQUEST
DESCRIPTOR.message_types_by_name['DeleteAllLevelResponse'] = _DELETEALLLEVELRESPONSE
DESCRIPTOR.message_types_by_name['DeleteAllLevelMultiRequest'] = _DELETEALLLEVELMULTIREQUEST
DESCRIPTOR.message_types_by_name['DeleteAllLevelMultiResponse'] = _DELETEALLLEVELMULTIRESPONSE
DESCRIPTOR.message_types_by_name['FloorSchedule'] = _FLOORSCHEDULE
DESCRIPTOR.message_types_by_name['FloorLevel'] = _FLOORLEVEL
DESCRIPTOR.message_types_by_name['GetFloorLevelListRequest'] = _GETFLOORLEVELLISTREQUEST
DESCRIPTOR.message_types_by_name['GetFloorLevelListResponse'] = _GETFLOORLEVELLISTRESPONSE
DESCRIPTOR.message_types_by_name['AddFloorLevelRequest'] = _ADDFLOORLEVELREQUEST
DESCRIPTOR.message_types_by_name['AddFloorLevelResponse'] = _ADDFLOORLEVELRESPONSE
DESCRIPTOR.message_types_by_name['AddFloorLevelMultiRequest'] = _ADDFLOORLEVELMULTIREQUEST
DESCRIPTOR.message_types_by_name['AddFloorLevelMultiResponse'] = _ADDFLOORLEVELMULTIRESPONSE
DESCRIPTOR.message_types_by_name['DeleteFloorLevelRequest'] = _DELETEFLOORLEVELREQUEST
DESCRIPTOR.message_types_by_name['DeleteFloorLevelResponse'] = _DELETEFLOORLEVELRESPONSE
DESCRIPTOR.message_types_by_name['DeleteFloorLevelMultiRequest'] = _DELETEFLOORLEVELMULTIREQUEST
DESCRIPTOR.message_types_by_name['DeleteFloorLevelMultiResponse'] = _DELETEFLOORLEVELMULTIRESPONSE
DESCRIPTOR.message_types_by_name['DeleteAllFloorLevelRequest'] = _DELETEALLFLOORLEVELREQUEST
DESCRIPTOR.message_types_by_name['DeleteAllFloorLevelResponse'] = _DELETEALLFLOORLEVELRESPONSE
DESCRIPTOR.message_types_by_name['DeleteAllFloorLevelMultiRequest'] = _DELETEALLFLOORLEVELMULTIREQUEST
DESCRIPTOR.message_types_by_name['DeleteAllFloorLevelMultiResponse'] = _DELETEALLFLOORLEVELMULTIRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetListRequest = _reflection.GeneratedProtocolMessageType('GetListRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETLISTREQUEST,
  __module__ = 'access_pb2'
  # @@protoc_insertion_point(class_scope:access.GetListRequest)
  ))
_sym_db.RegisterMessage(GetListRequest)

AccessGroup = _reflection.GeneratedProtocolMessageType('AccessGroup', (_message.Message,), dict(
  DESCRIPTOR = _ACCESSGROUP,
  __module__ = 'access_pb2'
  # @@protoc_insertion_point(class_scope:access.AccessGroup)
  ))
_sym_db.RegisterMessage(AccessGroup)

GetListResponse = _reflection.GeneratedProtocolMessageType('GetListResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETLISTRESPONSE,
  __module__ = 'access_pb2'
  # @@protoc_insertion_point(class_scope:access.GetListResponse)
  ))
_sym_db.RegisterMessage(GetListResponse)

AddRequest = _reflection.GeneratedProtocolMessageType('AddRequest', (_message.Message,), dict(
  DESCRIPTOR = _ADDREQUEST,
  __module__ = 'access_pb2'
  # @@protoc_insertion_point(class_scope:access.AddRequest)
  ))
_sym_db.RegisterMessage(AddRequest)

AddResponse = _reflection.GeneratedProtocolMessageType('AddResponse', (_message.Message,), dict(
  DESCRIPTOR = _ADDRESPONSE,
  __module__ = 'access_pb2'
  # @@protoc_insertion_point(class_scope:access.AddResponse)
  ))
_sym_db.RegisterMessage(AddResponse)

AddMultiRequest = _reflection.GeneratedProtocolMessageType('AddMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _ADDMULTIREQUEST,
  __module__ = 'access_pb2'
  # @@protoc_insertion_point(class_scope:access.AddMultiRequest)
  ))
_sym_db.RegisterMessage(AddMultiRequest)

AddMultiResponse = _reflection.GeneratedProtocolMessageType('AddMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _ADDMULTIRESPONSE,
  __module__ = 'access_pb2'
  # @@protoc_insertion_point(class_scope:access.AddMultiResponse)
  ))
_sym_db.RegisterMessage(AddMultiResponse)

DeleteRequest = _reflection.GeneratedProtocolMessageType('DeleteRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEREQUEST,
  __module__ = 'access_pb2'
  # @@protoc_insertion_point(class_scope:access.DeleteRequest)
  ))
_sym_db.RegisterMessage(DeleteRequest)

DeleteResponse = _reflection.GeneratedProtocolMessageType('DeleteResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETERESPONSE,
  __module__ = 'access_pb2'
  # @@protoc_insertion_point(class_scope:access.DeleteResponse)
  ))
_sym_db.RegisterMessage(DeleteResponse)

DeleteMultiRequest = _reflection.GeneratedProtocolMessageType('DeleteMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEMULTIREQUEST,
  __module__ = 'access_pb2'
  # @@protoc_insertion_point(class_scope:access.DeleteMultiRequest)
  ))
_sym_db.RegisterMessage(DeleteMultiRequest)

DeleteMultiResponse = _reflection.GeneratedProtocolMessageType('DeleteMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETEMULTIRESPONSE,
  __module__ = 'access_pb2'
  # @@protoc_insertion_point(class_scope:access.DeleteMultiResponse)
  ))
_sym_db.RegisterMessage(DeleteMultiResponse)

DeleteAllRequest = _reflection.GeneratedProtocolMessageType('DeleteAllRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEALLREQUEST,
  __module__ = 'access_pb2'
  # @@protoc_insertion_point(class_scope:access.DeleteAllRequest)
  ))
_sym_db.RegisterMessage(DeleteAllRequest)

DeleteAllResponse = _reflection.GeneratedProtocolMessageType('DeleteAllResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETEALLRESPONSE,
  __module__ = 'access_pb2'
  # @@protoc_insertion_point(class_scope:access.DeleteAllResponse)
  ))
_sym_db.RegisterMessage(DeleteAllResponse)

DeleteAllMultiRequest = _reflection.GeneratedProtocolMessageType('DeleteAllMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEALLMULTIREQUEST,
  __module__ = 'access_pb2'
  # @@protoc_insertion_point(class_scope:access.DeleteAllMultiRequest)
  ))
_sym_db.RegisterMessage(DeleteAllMultiRequest)

DeleteAllMultiResponse = _reflection.GeneratedProtocolMessageType('DeleteAllMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETEALLMULTIRESPONSE,
  __module__ = 'access_pb2'
  # @@protoc_insertion_point(class_scope:access.DeleteAllMultiResponse)
  ))
_sym_db.RegisterMessage(DeleteAllMultiResponse)

GetLevelListRequest = _reflection.GeneratedProtocolMessageType('GetLevelListRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETLEVELLISTREQUEST,
  __module__ = 'access_pb2'
  # @@protoc_insertion_point(class_scope:access.GetLevelListRequest)
  ))
_sym_db.RegisterMessage(GetLevelListRequest)

DoorSchedule = _reflection.GeneratedProtocolMessageType('DoorSchedule', (_message.Message,), dict(
  DESCRIPTOR = _DOORSCHEDULE,
  __module__ = 'access_pb2'
  # @@protoc_insertion_point(class_scope:access.DoorSchedule)
  ))
_sym_db.RegisterMessage(DoorSchedule)

AccessLevel = _reflection.GeneratedProtocolMessageType('AccessLevel', (_message.Message,), dict(
  DESCRIPTOR = _ACCESSLEVEL,
  __module__ = 'access_pb2'
  # @@protoc_insertion_point(class_scope:access.AccessLevel)
  ))
_sym_db.RegisterMessage(AccessLevel)

GetLevelListResponse = _reflection.GeneratedProtocolMessageType('GetLevelListResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETLEVELLISTRESPONSE,
  __module__ = 'access_pb2'
  # @@protoc_insertion_point(class_scope:access.GetLevelListResponse)
  ))
_sym_db.RegisterMessage(GetLevelListResponse)

AddLevelRequest = _reflection.GeneratedProtocolMessageType('AddLevelRequest', (_message.Message,), dict(
  DESCRIPTOR = _ADDLEVELREQUEST,
  __module__ = 'access_pb2'
  # @@protoc_insertion_point(class_scope:access.AddLevelRequest)
  ))
_sym_db.RegisterMessage(AddLevelRequest)

AddLevelResponse = _reflection.GeneratedProtocolMessageType('AddLevelResponse', (_message.Message,), dict(
  DESCRIPTOR = _ADDLEVELRESPONSE,
  __module__ = 'access_pb2'
  # @@protoc_insertion_point(class_scope:access.AddLevelResponse)
  ))
_sym_db.RegisterMessage(AddLevelResponse)

AddLevelMultiRequest = _reflection.GeneratedProtocolMessageType('AddLevelMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _ADDLEVELMULTIREQUEST,
  __module__ = 'access_pb2'
  # @@protoc_insertion_point(class_scope:access.AddLevelMultiRequest)
  ))
_sym_db.RegisterMessage(AddLevelMultiRequest)

AddLevelMultiResponse = _reflection.GeneratedProtocolMessageType('AddLevelMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _ADDLEVELMULTIRESPONSE,
  __module__ = 'access_pb2'
  # @@protoc_insertion_point(class_scope:access.AddLevelMultiResponse)
  ))
_sym_db.RegisterMessage(AddLevelMultiResponse)

DeleteLevelRequest = _reflection.GeneratedProtocolMessageType('DeleteLevelRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETELEVELREQUEST,
  __module__ = 'access_pb2'
  # @@protoc_insertion_point(class_scope:access.DeleteLevelRequest)
  ))
_sym_db.RegisterMessage(DeleteLevelRequest)

DeleteLevelResponse = _reflection.GeneratedProtocolMessageType('DeleteLevelResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETELEVELRESPONSE,
  __module__ = 'access_pb2'
  # @@protoc_insertion_point(class_scope:access.DeleteLevelResponse)
  ))
_sym_db.RegisterMessage(DeleteLevelResponse)

DeleteLevelMultiRequest = _reflection.GeneratedProtocolMessageType('DeleteLevelMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETELEVELMULTIREQUEST,
  __module__ = 'access_pb2'
  # @@protoc_insertion_point(class_scope:access.DeleteLevelMultiRequest)
  ))
_sym_db.RegisterMessage(DeleteLevelMultiRequest)

DeleteLevelMultiResponse = _reflection.GeneratedProtocolMessageType('DeleteLevelMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETELEVELMULTIRESPONSE,
  __module__ = 'access_pb2'
  # @@protoc_insertion_point(class_scope:access.DeleteLevelMultiResponse)
  ))
_sym_db.RegisterMessage(DeleteLevelMultiResponse)

DeleteAllLevelRequest = _reflection.GeneratedProtocolMessageType('DeleteAllLevelRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEALLLEVELREQUEST,
  __module__ = 'access_pb2'
  # @@protoc_insertion_point(class_scope:access.DeleteAllLevelRequest)
  ))
_sym_db.RegisterMessage(DeleteAllLevelRequest)

DeleteAllLevelResponse = _reflection.GeneratedProtocolMessageType('DeleteAllLevelResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETEALLLEVELRESPONSE,
  __module__ = 'access_pb2'
  # @@protoc_insertion_point(class_scope:access.DeleteAllLevelResponse)
  ))
_sym_db.RegisterMessage(DeleteAllLevelResponse)

DeleteAllLevelMultiRequest = _reflection.GeneratedProtocolMessageType('DeleteAllLevelMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEALLLEVELMULTIREQUEST,
  __module__ = 'access_pb2'
  # @@protoc_insertion_point(class_scope:access.DeleteAllLevelMultiRequest)
  ))
_sym_db.RegisterMessage(DeleteAllLevelMultiRequest)

DeleteAllLevelMultiResponse = _reflection.GeneratedProtocolMessageType('DeleteAllLevelMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETEALLLEVELMULTIRESPONSE,
  __module__ = 'access_pb2'
  # @@protoc_insertion_point(class_scope:access.DeleteAllLevelMultiResponse)
  ))
_sym_db.RegisterMessage(DeleteAllLevelMultiResponse)

FloorSchedule = _reflection.GeneratedProtocolMessageType('FloorSchedule', (_message.Message,), dict(
  DESCRIPTOR = _FLOORSCHEDULE,
  __module__ = 'access_pb2'
  # @@protoc_insertion_point(class_scope:access.FloorSchedule)
  ))
_sym_db.RegisterMessage(FloorSchedule)

FloorLevel = _reflection.GeneratedProtocolMessageType('FloorLevel', (_message.Message,), dict(
  DESCRIPTOR = _FLOORLEVEL,
  __module__ = 'access_pb2'
  # @@protoc_insertion_point(class_scope:access.FloorLevel)
  ))
_sym_db.RegisterMessage(FloorLevel)

GetFloorLevelListRequest = _reflection.GeneratedProtocolMessageType('GetFloorLevelListRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETFLOORLEVELLISTREQUEST,
  __module__ = 'access_pb2'
  # @@protoc_insertion_point(class_scope:access.GetFloorLevelListRequest)
  ))
_sym_db.RegisterMessage(GetFloorLevelListRequest)

GetFloorLevelListResponse = _reflection.GeneratedProtocolMessageType('GetFloorLevelListResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETFLOORLEVELLISTRESPONSE,
  __module__ = 'access_pb2'
  # @@protoc_insertion_point(class_scope:access.GetFloorLevelListResponse)
  ))
_sym_db.RegisterMessage(GetFloorLevelListResponse)

AddFloorLevelRequest = _reflection.GeneratedProtocolMessageType('AddFloorLevelRequest', (_message.Message,), dict(
  DESCRIPTOR = _ADDFLOORLEVELREQUEST,
  __module__ = 'access_pb2'
  # @@protoc_insertion_point(class_scope:access.AddFloorLevelRequest)
  ))
_sym_db.RegisterMessage(AddFloorLevelRequest)

AddFloorLevelResponse = _reflection.GeneratedProtocolMessageType('AddFloorLevelResponse', (_message.Message,), dict(
  DESCRIPTOR = _ADDFLOORLEVELRESPONSE,
  __module__ = 'access_pb2'
  # @@protoc_insertion_point(class_scope:access.AddFloorLevelResponse)
  ))
_sym_db.RegisterMessage(AddFloorLevelResponse)

AddFloorLevelMultiRequest = _reflection.GeneratedProtocolMessageType('AddFloorLevelMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _ADDFLOORLEVELMULTIREQUEST,
  __module__ = 'access_pb2'
  # @@protoc_insertion_point(class_scope:access.AddFloorLevelMultiRequest)
  ))
_sym_db.RegisterMessage(AddFloorLevelMultiRequest)

AddFloorLevelMultiResponse = _reflection.GeneratedProtocolMessageType('AddFloorLevelMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _ADDFLOORLEVELMULTIRESPONSE,
  __module__ = 'access_pb2'
  # @@protoc_insertion_point(class_scope:access.AddFloorLevelMultiResponse)
  ))
_sym_db.RegisterMessage(AddFloorLevelMultiResponse)

DeleteFloorLevelRequest = _reflection.GeneratedProtocolMessageType('DeleteFloorLevelRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEFLOORLEVELREQUEST,
  __module__ = 'access_pb2'
  # @@protoc_insertion_point(class_scope:access.DeleteFloorLevelRequest)
  ))
_sym_db.RegisterMessage(DeleteFloorLevelRequest)

DeleteFloorLevelResponse = _reflection.GeneratedProtocolMessageType('DeleteFloorLevelResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETEFLOORLEVELRESPONSE,
  __module__ = 'access_pb2'
  # @@protoc_insertion_point(class_scope:access.DeleteFloorLevelResponse)
  ))
_sym_db.RegisterMessage(DeleteFloorLevelResponse)

DeleteFloorLevelMultiRequest = _reflection.GeneratedProtocolMessageType('DeleteFloorLevelMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEFLOORLEVELMULTIREQUEST,
  __module__ = 'access_pb2'
  # @@protoc_insertion_point(class_scope:access.DeleteFloorLevelMultiRequest)
  ))
_sym_db.RegisterMessage(DeleteFloorLevelMultiRequest)

DeleteFloorLevelMultiResponse = _reflection.GeneratedProtocolMessageType('DeleteFloorLevelMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETEFLOORLEVELMULTIRESPONSE,
  __module__ = 'access_pb2'
  # @@protoc_insertion_point(class_scope:access.DeleteFloorLevelMultiResponse)
  ))
_sym_db.RegisterMessage(DeleteFloorLevelMultiResponse)

DeleteAllFloorLevelRequest = _reflection.GeneratedProtocolMessageType('DeleteAllFloorLevelRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEALLFLOORLEVELREQUEST,
  __module__ = 'access_pb2'
  # @@protoc_insertion_point(class_scope:access.DeleteAllFloorLevelRequest)
  ))
_sym_db.RegisterMessage(DeleteAllFloorLevelRequest)

DeleteAllFloorLevelResponse = _reflection.GeneratedProtocolMessageType('DeleteAllFloorLevelResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETEALLFLOORLEVELRESPONSE,
  __module__ = 'access_pb2'
  # @@protoc_insertion_point(class_scope:access.DeleteAllFloorLevelResponse)
  ))
_sym_db.RegisterMessage(DeleteAllFloorLevelResponse)

DeleteAllFloorLevelMultiRequest = _reflection.GeneratedProtocolMessageType('DeleteAllFloorLevelMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEALLFLOORLEVELMULTIREQUEST,
  __module__ = 'access_pb2'
  # @@protoc_insertion_point(class_scope:access.DeleteAllFloorLevelMultiRequest)
  ))
_sym_db.RegisterMessage(DeleteAllFloorLevelMultiRequest)

DeleteAllFloorLevelMultiResponse = _reflection.GeneratedProtocolMessageType('DeleteAllFloorLevelMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETEALLFLOORLEVELMULTIRESPONSE,
  __module__ = 'access_pb2'
  # @@protoc_insertion_point(class_scope:access.DeleteAllFloorLevelMultiResponse)
  ))
_sym_db.RegisterMessage(DeleteAllFloorLevelMultiResponse)


DESCRIPTOR._options = None

_ACCESS = _descriptor.ServiceDescriptor(
  name='Access',
  full_name='access.Access',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=2637,
  serialized_end=4301,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetList',
    full_name='access.Access.GetList',
    index=0,
    containing_service=None,
    input_type=_GETLISTREQUEST,
    output_type=_GETLISTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Add',
    full_name='access.Access.Add',
    index=1,
    containing_service=None,
    input_type=_ADDREQUEST,
    output_type=_ADDRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AddMulti',
    full_name='access.Access.AddMulti',
    index=2,
    containing_service=None,
    input_type=_ADDMULTIREQUEST,
    output_type=_ADDMULTIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='access.Access.Delete',
    index=3,
    containing_service=None,
    input_type=_DELETEREQUEST,
    output_type=_DELETERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteMulti',
    full_name='access.Access.DeleteMulti',
    index=4,
    containing_service=None,
    input_type=_DELETEMULTIREQUEST,
    output_type=_DELETEMULTIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAll',
    full_name='access.Access.DeleteAll',
    index=5,
    containing_service=None,
    input_type=_DELETEALLREQUEST,
    output_type=_DELETEALLRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAllMulti',
    full_name='access.Access.DeleteAllMulti',
    index=6,
    containing_service=None,
    input_type=_DELETEALLMULTIREQUEST,
    output_type=_DELETEALLMULTIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetLevelList',
    full_name='access.Access.GetLevelList',
    index=7,
    containing_service=None,
    input_type=_GETLEVELLISTREQUEST,
    output_type=_GETLEVELLISTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AddLevel',
    full_name='access.Access.AddLevel',
    index=8,
    containing_service=None,
    input_type=_ADDLEVELREQUEST,
    output_type=_ADDLEVELRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AddLevelMulti',
    full_name='access.Access.AddLevelMulti',
    index=9,
    containing_service=None,
    input_type=_ADDLEVELMULTIREQUEST,
    output_type=_ADDLEVELMULTIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteLevel',
    full_name='access.Access.DeleteLevel',
    index=10,
    containing_service=None,
    input_type=_DELETELEVELREQUEST,
    output_type=_DELETELEVELRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteLevelMulti',
    full_name='access.Access.DeleteLevelMulti',
    index=11,
    containing_service=None,
    input_type=_DELETELEVELMULTIREQUEST,
    output_type=_DELETELEVELMULTIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAllLevel',
    full_name='access.Access.DeleteAllLevel',
    index=12,
    containing_service=None,
    input_type=_DELETEALLLEVELREQUEST,
    output_type=_DELETEALLLEVELRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAllLevelMulti',
    full_name='access.Access.DeleteAllLevelMulti',
    index=13,
    containing_service=None,
    input_type=_DELETEALLLEVELMULTIREQUEST,
    output_type=_DELETEALLLEVELMULTIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetFloorLevelList',
    full_name='access.Access.GetFloorLevelList',
    index=14,
    containing_service=None,
    input_type=_GETFLOORLEVELLISTREQUEST,
    output_type=_GETFLOORLEVELLISTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AddFloorLevel',
    full_name='access.Access.AddFloorLevel',
    index=15,
    containing_service=None,
    input_type=_ADDFLOORLEVELREQUEST,
    output_type=_ADDFLOORLEVELRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AddFloorLevelMulti',
    full_name='access.Access.AddFloorLevelMulti',
    index=16,
    containing_service=None,
    input_type=_ADDFLOORLEVELMULTIREQUEST,
    output_type=_ADDFLOORLEVELMULTIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteFloorLevel',
    full_name='access.Access.DeleteFloorLevel',
    index=17,
    containing_service=None,
    input_type=_DELETEFLOORLEVELREQUEST,
    output_type=_DELETEFLOORLEVELRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteFloorLevelMulti',
    full_name='access.Access.DeleteFloorLevelMulti',
    index=18,
    containing_service=None,
    input_type=_DELETEFLOORLEVELMULTIREQUEST,
    output_type=_DELETEFLOORLEVELMULTIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAllFloorLevel',
    full_name='access.Access.DeleteAllFloorLevel',
    index=19,
    containing_service=None,
    input_type=_DELETEALLFLOORLEVELREQUEST,
    output_type=_DELETEALLFLOORLEVELRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAllFloorLevelMulti',
    full_name='access.Access.DeleteAllFloorLevelMulti',
    index=20,
    containing_service=None,
    input_type=_DELETEALLFLOORLEVELMULTIREQUEST,
    output_type=_DELETEALLFLOORLEVELMULTIRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_ACCESS)

DESCRIPTOR.services_by_name['Access'] = _ACCESS

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from biostarPython.service import schedule_pb2 as schedule__pb2


class ScheduleStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetList = channel.unary_unary(
        '/schedule.Schedule/GetList',
        request_serializer=schedule__pb2.GetListRequest.SerializeToString,
        response_deserializer=schedule__pb2.GetListResponse.FromString,
        )
    self.Add = channel.unary_unary(
        '/schedule.Schedule/Add',
        request_serializer=schedule__pb2.AddRequest.SerializeToString,
        response_deserializer=schedule__pb2.AddResponse.FromString,
        )
    self.AddMulti = channel.unary_unary(
        '/schedule.Schedule/AddMulti',
        request_serializer=schedule__pb2.AddMultiRequest.SerializeToString,
        response_deserializer=schedule__pb2.AddMultiResponse.FromString,
        )
    self.Delete = channel.unary_unary(
        '/schedule.Schedule/Delete',
        request_serializer=schedule__pb2.DeleteRequest.SerializeToString,
        response_deserializer=schedule__pb2.DeleteResponse.FromString,
        )
    self.DeleteMulti = channel.unary_unary(
        '/schedule.Schedule/DeleteMulti',
        request_serializer=schedule__pb2.DeleteMultiRequest.SerializeToString,
        response_deserializer=schedule__pb2.DeleteMultiResponse.FromString,
        )
    self.DeleteAll = channel.unary_unary(
        '/schedule.Schedule/DeleteAll',
        request_serializer=schedule__pb2.DeleteAllRequest.SerializeToString,
        response_deserializer=schedule__pb2.DeleteAllResponse.FromString,
        )
    self.DeleteAllMulti = channel.unary_unary(
        '/schedule.Schedule/DeleteAllMulti',
        request_serializer=schedule__pb2.DeleteAllMultiRequest.SerializeToString,
        response_deserializer=schedule__pb2.DeleteAllMultiResponse.FromString,
        )
    self.GetHolidayList = channel.unary_unary(
        '/schedule.Schedule/GetHolidayList',
        request_serializer=schedule__pb2.GetHolidayListRequest.SerializeToString,
        response_deserializer=schedule__pb2.GetHolidayListResponse.FromString,
        )
    self.AddHoliday = channel.unary_unary(
        '/schedule.Schedule/AddHoliday',
        request_serializer=schedule__pb2.AddHolidayRequest.SerializeToString,
        response_deserializer=schedule__pb2.AddHolidayResponse.FromString,
        )
    self.AddHolidayMulti = channel.unary_unary(
        '/schedule.Schedule/AddHolidayMulti',
        request_serializer=schedule__pb2.AddHolidayMultiRequest.SerializeToString,
        response_deserializer=schedule__pb2.AddHolidayMultiResponse.FromString,
        )
    self.DeleteHoliday = channel.unary_unary(
        '/schedule.Schedule/DeleteHoliday',
        request_serializer=schedule__pb2.DeleteHolidayRequest.SerializeToString,
        response_deserializer=schedule__pb2.DeleteHolidayResponse.FromString,
        )
    self.DeleteHolidayMulti = channel.unary_unary(
        '/schedule.Schedule/DeleteHolidayMulti',
        request_serializer=schedule__pb2.DeleteHolidayMultiRequest.SerializeToString,
        response_deserializer=schedule__pb2.DeleteHolidayMultiResponse.FromString,
        )
    self.DeleteAllHoliday = channel.unary_unary(
        '/schedule.Schedule/DeleteAllHoliday',
        request_serializer=schedule__pb2.DeleteAllHolidayRequest.SerializeToString,
        response_deserializer=schedule__pb2.DeleteAllHolidayResponse.FromString,
        )
    self.DeleteAllHolidayMulti = channel.unary_unary(
        '/schedule.Schedule/DeleteAllHolidayMulti',
        request_serializer=schedule__pb2.DeleteAllHolidayMultiRequest.SerializeToString,
        response_deserializer=schedule__pb2.DeleteAllHolidayMultiResponse.FromString,
        )


class ScheduleServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def GetList(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Add(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def AddMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Delete(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteAll(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteAllMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetHolidayList(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def AddHoliday(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def AddHolidayMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteHoliday(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteHolidayMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteAllHoliday(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteAllHolidayMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_ScheduleServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetList': grpc.unary_unary_rpc_method_handler(
          servicer.GetList,
          request_deserializer=schedule__pb2.GetListRequest.FromString,
          response_serializer=schedule__pb2.GetListResponse.SerializeToString,
      ),
      'Add': grpc.unary_unary_rpc_method_handler(
          servicer.Add,
          request_deserializer=schedule__pb2.AddRequest.FromString,
          response_serializer=schedule__pb2.AddResponse.SerializeToString,
      ),
      'AddMulti': grpc.unary_unary_rpc_method_handler(
          servicer.AddMulti,
          request_deserializer=schedule__pb2.AddMultiRequest.FromString,
          response_serializer=schedule__pb2.AddMultiResponse.SerializeToString,
      ),
      'Delete': grpc.unary_unary_rpc_method_handler(
          servicer.Delete,
          request_deserializer=schedule__pb2.DeleteRequest.FromString,
          response_serializer=schedule__pb2.DeleteResponse.SerializeToString,
      ),
      'DeleteMulti': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteMulti,
          request_deserializer=schedule__pb2.DeleteMultiRequest.FromString,
          response_serializer=schedule__pb2.DeleteMultiResponse.SerializeToString,
      ),
      'DeleteAll': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteAll,
          request_deserializer=schedule__pb2.DeleteAllRequest.FromString,
          response_serializer=schedule__pb2.DeleteAllResponse.SerializeToString,
      ),
      'DeleteAllMulti': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteAllMulti,
          request_deserializer=schedule__pb2.DeleteAllMultiRequest.FromString,
          response_serializer=schedule__pb2.DeleteAllMultiResponse.SerializeToString,
      ),
      'GetHolidayList': grpc.unary_unary_rpc_method_handler(
          servicer.GetHolidayList,
          request_deserializer=schedule__pb2.GetHolidayListRequest.FromString,
          response_serializer=schedule__pb2.GetHolidayListResponse.SerializeToString,
      ),
      'AddHoliday': grpc.unary_unary_rpc_method_handler(
          servicer.AddHoliday,
          request_deserializer=schedule__pb2.AddHolidayRequest.FromString,
          response_serializer=schedule__pb2.AddHolidayResponse.SerializeToString,
      ),
      'AddHolidayMulti': grpc.unary_unary_rpc_method_handler(
          servicer.AddHolidayMulti,
          request_deserializer=schedule__pb2.AddHolidayMultiRequest.FromString,
          response_serializer=schedule__pb2.AddHolidayMultiResponse.SerializeToString,
      ),
      'DeleteHoliday': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteHoliday,
          request_deserializer=schedule__pb2.DeleteHolidayRequest.FromString,
          response_serializer=schedule__pb2.DeleteHolidayResponse.SerializeToString,
      ),
      'DeleteHolidayMulti': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteHolidayMulti,
          request_deserializer=schedule__pb2.DeleteHolidayMultiRequest.FromString,
          response_serializer=schedule__pb2.DeleteHolidayMultiResponse.SerializeToString,
      ),
      'DeleteAllHoliday': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteAllHoliday,
          request_deserializer=schedule__pb2.DeleteAllHolidayRequest.FromString,
          response_serializer=schedule__pb2.DeleteAllHolidayResponse.SerializeToString,
      ),
      'DeleteAllHolidayMulti': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteAllHolidayMulti,
          request_deserializer=schedule__pb2.DeleteAllHolidayMultiRequest.FromString,
          response_serializer=schedule__pb2.DeleteAllHolidayMultiResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'schedule.Schedule', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rs485.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biostarPython.service import device_pb2 as device__pb2
from biostarPython.service import err_pb2 as err__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rs485.proto',
  package='rs485',
  syntax='proto3',
  serialized_options=_b('\n\030com.supremainc.sdk.rs485P\001Z\025biostar/service/rs485'),
  serialized_pb=_b('\n\x0brs485.proto\x12\x05rs485\x1a\x0c\x64\x65vice.proto\x1a\terr.proto\"v\n\x0fSlaveDeviceInfo\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\x1a\n\x04type\x18\x02 \x01(\x0e\x32\x0c.device.Type\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\x12\x11\n\tconnected\x18\x04 \x01(\x08\x12\x11\n\tchannelID\x18\x05 \x01(\r\"\'\n\x13SearchDeviceRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"B\n\x14SearchDeviceResponse\x12*\n\nslaveInfos\x18\x01 \x03(\x0b\x32\x16.rs485.SlaveDeviceInfo\"P\n\x10SetDeviceRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12*\n\nslaveInfos\x18\x02 \x03(\x0b\x32\x16.rs485.SlaveDeviceInfo\"\x13\n\x11SetDeviceResponse\"$\n\x10GetDeviceRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"?\n\x11GetDeviceResponse\x12*\n\nslaveInfos\x18\x02 \x03(\x0b\x32\x16.rs485.SlaveDeviceInfo\"\x82\x01\n\x11IntelligentPDInfo\x12\x18\n\x10useExceptionCode\x18\x01 \x01(\x08\x12\x15\n\rexceptionCode\x18\x02 \x01(\x0c\x12,\n\x0coutputFormat\x18\x03 \x01(\x0e\x32\x16.rs485.IPDOutputFormat\x12\x0e\n\x06OSDPID\x18\x04 \x01(\r\"N\n\x0cRS485Channel\x12\x11\n\tchannelID\x18\x01 \x01(\r\x12\x19\n\x04mode\x18\x02 \x01(\x0e\x32\x0b.rs485.Mode\x12\x10\n\x08\x62\x61udRate\x18\x03 \x01(\r\"g\n\x0bRS485Config\x12%\n\x08\x63hannels\x18\x01 \x03(\x0b\x32\x13.rs485.RS485Channel\x12\x31\n\x0fintelligentInfo\x18\x02 \x01(\x0b\x32\x18.rs485.IntelligentPDInfo\"$\n\x10GetConfigRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"7\n\x11GetConfigResponse\x12\"\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x12.rs485.RS485Config\"H\n\x10SetConfigRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\"\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x12.rs485.RS485Config\"\x13\n\x11SetConfigResponse\"N\n\x15SetConfigMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12\"\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x12.rs485.RS485Config\"B\n\x16SetConfigMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse*:\n\x04Mode\x12\x0b\n\x07NOT_USE\x10\x00\x12\n\n\x06MASTER\x10\x01\x12\t\n\x05SLAVE\x10\x02\x12\x0e\n\nSTANDALONE\x10\x03*)\n\x0fIPDOutputFormat\x12\n\n\x06\x43\x41RDID\x10\x00\x12\n\n\x06USERID\x10\x01\x32\x9f\x03\n\x05RS485\x12G\n\x0cSearchDevice\x12\x1a.rs485.SearchDeviceRequest\x1a\x1b.rs485.SearchDeviceResponse\x12>\n\tGetDevice\x12\x17.rs485.GetDeviceRequest\x1a\x18.rs485.GetDeviceResponse\x12>\n\tSetDevice\x12\x17.rs485.SetDeviceRequest\x1a\x18.rs485.SetDeviceResponse\x12>\n\tGetConfig\x12\x17.rs485.GetConfigRequest\x1a\x18.rs485.GetConfigResponse\x12>\n\tSetConfig\x12\x17.rs485.SetConfigRequest\x1a\x18.rs485.SetConfigResponse\x12M\n\x0eSetConfigMulti\x12\x1c.rs485.SetConfigMultiRequest\x1a\x1d.rs485.SetConfigMultiResponseB3\n\x18\x63om.supremainc.sdk.rs485P\x01Z\x15\x62iostar/service/rs485b\x06proto3')
  ,
  dependencies=[device__pb2.DESCRIPTOR,err__pb2.DESCRIPTOR,])

_MODE = _descriptor.EnumDescriptor(
  name='Mode',
  full_name='rs485.Mode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NOT_USE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MASTER', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SLAVE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STANDALONE', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1138,
  serialized_end=1196,
)
_sym_db.RegisterEnumDescriptor(_MODE)

Mode = enum_type_wrapper.EnumTypeWrapper(_MODE)
_IPDOUTPUTFORMAT = _descriptor.EnumDescriptor(
  name='IPDOutputFormat',
  full_name='rs485.IPDOutputFormat',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CARDID', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='USERID', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1198,
  serialized_end=1239,
)
_sym_db.RegisterEnumDescriptor(_IPDOUTPUTFORMAT)

IPDOutputFormat = enum_type_wrapper.EnumTypeWrapper(_IPDOUTPUTFORMAT)
NOT_USE = 0
MASTER = 1
SLAVE = 2
STANDALONE = 3
CARDID = 0
USERID = 1



_SLAVEDEVICEINFO = _descriptor.Descriptor(
  name='SlaveDeviceInfo',
  full_name='rs485.SlaveDeviceInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='rs485.SlaveDeviceInfo.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='rs485.SlaveDeviceInfo.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='rs485.SlaveDeviceInfo.enabled', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='connected', full_name='rs485.SlaveDeviceInfo.connected', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='channelID', full_name='rs485.SlaveDeviceInfo.channelID', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=47,
  serialized_end=165,
)


_SEARCHDEVICEREQUEST = _descriptor.Descriptor(
  name='SearchDeviceRequest',
  full_name='rs485.SearchDeviceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='rs485.SearchDeviceRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=167,
  serialized_end=206,
)


_SEARCHDEVICERESPONSE = _descriptor.Descriptor(
  name='SearchDeviceResponse',
  full_name='rs485.SearchDeviceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='slaveInfos', full_name='rs485.SearchDeviceResponse.slaveInfos', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=208,
  serialized_end=274,
)


_SETDEVICEREQUEST = _descriptor.Descriptor(
  name='SetDeviceRequest',
  full_name='rs485.SetDeviceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='rs485.SetDeviceRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slaveInfos', full_name='rs485.SetDeviceRequest.slaveInfos', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=276,
  serialized_end=356,
)


_SETDEVICERESPONSE = _descriptor.Descriptor(
  name='SetDeviceResponse',
  full_name='rs485.SetDeviceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=358,
  serialized_end=377,
)


_GETDEVICEREQUEST = _descriptor.Descriptor(
  name='GetDeviceRequest',
  full_name='rs485.GetDeviceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='rs485.GetDeviceRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=379,
  serialized_end=415,
)


_GETDEVICERESPONSE = _descriptor.Descriptor(
  name='GetDeviceResponse',
  full_name='rs485.GetDeviceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='slaveInfos', full_name='rs485.GetDeviceResponse.slaveInfos', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=417,
  serialized_end=480,
)


_INTELLIGENTPDINFO = _descriptor.Descriptor(
  name='IntelligentPDInfo',
  full_name='rs485.IntelligentPDInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='useExceptionCode', full_name='rs485.IntelligentPDInfo.useExceptionCode', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exceptionCode', full_name='rs485.IntelligentPDInfo.exceptionCode', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outputFormat', full_name='rs485.IntelligentPDInfo.outputFormat', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='OSDPID', full_name='rs485.IntelligentPDInfo.OSDPID', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=483,
  serialized_end=613,
)


_RS485CHANNEL = _descriptor.Descriptor(
  name='RS485Channel',
  full_name='rs485.RS485Channel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channelID', full_name='rs485.RS485Channel.channelID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mode', full_name='rs485.RS485Channel.mode', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='baudRate', full_name='rs485.RS485Channel.baudRate', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=615,
  serialized_end=693,
)


_RS485CONFIG = _descriptor.Descriptor(
  name='RS485Config',
  full_name='rs485.RS485Config',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channels', full_name='rs485.RS485Config.channels', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='intelligentInfo', full_name='rs485.RS485Config.intelligentInfo', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=695,
  serialized_end=798,
)


_GETCONFIGREQUEST = _descriptor.Descriptor(
  name='GetConfigRequest',
  full_name='rs485.GetConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='rs485.GetConfigRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=800,
  serialized_end=836,
)


_GETCONFIGRESPONSE = _descriptor.Descriptor(
  name='GetConfigResponse',
  full_name='rs485.GetConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='rs485.GetConfigResponse.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=838,
  serialized_end=893,
)


_SETCONFIGREQUEST = _descriptor.Descriptor(
  name='SetConfigRequest',
  full_name='rs485.SetConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='rs485.SetConfigRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='rs485.SetConfigRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=895,
  serialized_end=967,
)


_SETCONFIGRESPONSE = _descriptor.Descriptor(
  name='SetConfigResponse',
  full_name='rs485.SetConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=969,
  serialized_end=988,
)


_SETCONFIGMULTIREQUEST = _descriptor.Descriptor(
  name='SetConfigMultiRequest',
  full_name='rs485.SetConfigMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='rs485.SetConfigMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='rs485.SetConfigMultiRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=990,
  serialized_end=1068,
)


_SETCONFIGMULTIRESPONSE = _descriptor.Descriptor(
  name='SetConfigMultiResponse',
  full_name='rs485.SetConfigMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='rs485.SetConfigMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1070,
  serialized_end=1136,
)

_SLAVEDEVICEINFO.fields_by_name['type'].enum_type = device__pb2._TYPE
_SEARCHDEVICERESPONSE.fields_by_name['slaveInfos'].message_type = _SLAVEDEVICEINFO
_SETDEVICEREQUEST.fields_by_name['slaveInfos'].message_type = _SLAVEDEVICEINFO
_GETDEVICERESPONSE.fields_by_name['slaveInfos'].message_type = _SLAVEDEVICEINFO
_INTELLIGENTPDINFO.fields_by_name['outputFormat'].enum_type = _IPDOUTPUTFORMAT
_RS485CHANNEL.fields_by_name['mode'].enum_type = _MODE
_RS485CONFIG.fields_by_name['channels'].message_type = _RS485CHANNEL
_RS485CONFIG.fields_by_name['intelligentInfo'].message_type = _INTELLIGENTPDINFO
_GETCONFIGRESPONSE.fields_by_name['config'].message_type = _RS485CONFIG
_SETCONFIGREQUEST.fields_by_name['config'].message_type = _RS485CONFIG
_SETCONFIGMULTIREQUEST.fields_by_name['config'].message_type = _RS485CONFIG
_SETCONFIGMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
DESCRIPTOR.message_types_by_name['SlaveDeviceInfo'] = _SLAVEDEVICEINFO
DESCRIPTOR.message_types_by_name['SearchDeviceRequest'] = _SEARCHDEVICEREQUEST
DESCRIPTOR.message_types_by_name['SearchDeviceResponse'] = _SEARCHDEVICERESPONSE
DESCRIPTOR.message_types_by_name['SetDeviceRequest'] = _SETDEVICEREQUEST
DESCRIPTOR.message_types_by_name['SetDeviceResponse'] = _SETDEVICERESPONSE
DESCRIPTOR.message_types_by_name['GetDeviceRequest'] = _GETDEVICEREQUEST
DESCRIPTOR.message_types_by_name['GetDeviceResponse'] = _GETDEVICERESPONSE
DESCRIPTOR.message_types_by_name['IntelligentPDInfo'] = _INTELLIGENTPDINFO
DESCRIPTOR.message_types_by_name['RS485Channel'] = _RS485CHANNEL
DESCRIPTOR.message_types_by_name['RS485Config'] = _RS485CONFIG
DESCRIPTOR.message_types_by_name['GetConfigRequest'] = _GETCONFIGREQUEST
DESCRIPTOR.message_types_by_name['GetConfigResponse'] = _GETCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['SetConfigRequest'] = _SETCONFIGREQUEST
DESCRIPTOR.message_types_by_name['SetConfigResponse'] = _SETCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['SetConfigMultiRequest'] = _SETCONFIGMULTIREQUEST
DESCRIPTOR.message_types_by_name['SetConfigMultiResponse'] = _SETCONFIGMULTIRESPONSE
DESCRIPTOR.enum_types_by_name['Mode'] = _MODE
DESCRIPTOR.enum_types_by_name['IPDOutputFormat'] = _IPDOUTPUTFORMAT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SlaveDeviceInfo = _reflection.GeneratedProtocolMessageType('SlaveDeviceInfo', (_message.Message,), dict(
  DESCRIPTOR = _SLAVEDEVICEINFO,
  __module__ = 'rs485_pb2'
  # @@protoc_insertion_point(class_scope:rs485.SlaveDeviceInfo)
  ))
_sym_db.RegisterMessage(SlaveDeviceInfo)

SearchDeviceRequest = _reflection.GeneratedProtocolMessageType('SearchDeviceRequest', (_message.Message,), dict(
  DESCRIPTOR = _SEARCHDEVICEREQUEST,
  __module__ = 'rs485_pb2'
  # @@protoc_insertion_point(class_scope:rs485.SearchDeviceRequest)
  ))
_sym_db.RegisterMessage(SearchDeviceRequest)

SearchDeviceResponse = _reflection.GeneratedProtocolMessageType('SearchDeviceResponse', (_message.Message,), dict(
  DESCRIPTOR = _SEARCHDEVICERESPONSE,
  __module__ = 'rs485_pb2'
  # @@protoc_insertion_point(class_scope:rs485.SearchDeviceResponse)
  ))
_sym_db.RegisterMessage(SearchDeviceResponse)

SetDeviceRequest = _reflection.GeneratedProtocolMessageType('SetDeviceRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETDEVICEREQUEST,
  __module__ = 'rs485_pb2'
  # @@protoc_insertion_point(class_scope:rs485.SetDeviceRequest)
  ))
_sym_db.RegisterMessage(SetDeviceRequest)

SetDeviceResponse = _reflection.GeneratedProtocolMessageType('SetDeviceResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETDEVICERESPONSE,
  __module__ = 'rs485_pb2'
  # @@protoc_insertion_point(class_scope:rs485.SetDeviceResponse)
  ))
_sym_db.RegisterMessage(SetDeviceResponse)

GetDeviceRequest = _reflection.GeneratedProtocolMessageType('GetDeviceRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETDEVICEREQUEST,
  __module__ = 'rs485_pb2'
  # @@protoc_insertion_point(class_scope:rs485.GetDeviceRequest)
  ))
_sym_db.RegisterMessage(GetDeviceRequest)

GetDeviceResponse = _reflection.GeneratedProtocolMessageType('GetDeviceResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETDEVICERESPONSE,
  __module__ = 'rs485_pb2'
  # @@protoc_insertion_point(class_scope:rs485.GetDeviceResponse)
  ))
_sym_db.RegisterMessage(GetDeviceResponse)

IntelligentPDInfo = _reflection.GeneratedProtocolMessageType('IntelligentPDInfo', (_message.Message,), dict(
  DESCRIPTOR = _INTELLIGENTPDINFO,
  __module__ = 'rs485_pb2'
  # @@protoc_insertion_point(class_scope:rs485.IntelligentPDInfo)
  ))
_sym_db.RegisterMessage(IntelligentPDInfo)

RS485Channel = _reflection.GeneratedProtocolMessageType('RS485Channel', (_message.Message,), dict(
  DESCRIPTOR = _RS485CHANNEL,
  __module__ = 'rs485_pb2'
  # @@protoc_insertion_point(class_scope:rs485.RS485Channel)
  ))
_sym_db.RegisterMessage(RS485Channel)

RS485Config = _reflection.GeneratedProtocolMessageType('RS485Config', (_message.Message,), dict(
  DESCRIPTOR = _RS485CONFIG,
  __module__ = 'rs485_pb2'
  # @@protoc_insertion_point(class_scope:rs485.RS485Config)
  ))
_sym_db.RegisterMessage(RS485Config)

GetConfigRequest = _reflection.GeneratedProtocolMessageType('GetConfigRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETCONFIGREQUEST,
  __module__ = 'rs485_pb2'
  # @@protoc_insertion_point(class_scope:rs485.GetConfigRequest)
  ))
_sym_db.RegisterMessage(GetConfigRequest)

GetConfigResponse = _reflection.GeneratedProtocolMessageType('GetConfigResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETCONFIGRESPONSE,
  __module__ = 'rs485_pb2'
  # @@protoc_insertion_point(class_scope:rs485.GetConfigResponse)
  ))
_sym_db.RegisterMessage(GetConfigResponse)

SetConfigRequest = _reflection.GeneratedProtocolMessageType('SetConfigRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGREQUEST,
  __module__ = 'rs485_pb2'
  # @@protoc_insertion_point(class_scope:rs485.SetConfigRequest)
  ))
_sym_db.RegisterMessage(SetConfigRequest)

SetConfigResponse = _reflection.GeneratedProtocolMessageType('SetConfigResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGRESPONSE,
  __module__ = 'rs485_pb2'
  # @@protoc_insertion_point(class_scope:rs485.SetConfigResponse)
  ))
_sym_db.RegisterMessage(SetConfigResponse)

SetConfigMultiRequest = _reflection.GeneratedProtocolMessageType('SetConfigMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGMULTIREQUEST,
  __module__ = 'rs485_pb2'
  # @@protoc_insertion_point(class_scope:rs485.SetConfigMultiRequest)
  ))
_sym_db.RegisterMessage(SetConfigMultiRequest)

SetConfigMultiResponse = _reflection.GeneratedProtocolMessageType('SetConfigMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGMULTIRESPONSE,
  __module__ = 'rs485_pb2'
  # @@protoc_insertion_point(class_scope:rs485.SetConfigMultiResponse)
  ))
_sym_db.RegisterMessage(SetConfigMultiResponse)


DESCRIPTOR._options = None

_RS485 = _descriptor.ServiceDescriptor(
  name='RS485',
  full_name='rs485.RS485',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1242,
  serialized_end=1657,
  methods=[
  _descriptor.MethodDescriptor(
    name='SearchDevice',
    full_name='rs485.RS485.SearchDevice',
    index=0,
    containing_service=None,
    input_type=_SEARCHDEVICEREQUEST,
    output_type=_SEARCHDEVICERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetDevice',
    full_name='rs485.RS485.GetDevice',
    index=1,
    containing_service=None,
    input_type=_GETDEVICEREQUEST,
    output_type=_GETDEVICERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetDevice',
    full_name='rs485.RS485.SetDevice',
    index=2,
    containing_service=None,
    input_type=_SETDEVICEREQUEST,
    output_type=_SETDEVICERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetConfig',
    full_name='rs485.RS485.GetConfig',
    index=3,
    containing_service=None,
    input_type=_GETCONFIGREQUEST,
    output_type=_GETCONFIGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetConfig',
    full_name='rs485.RS485.SetConfig',
    index=4,
    containing_service=None,
    input_type=_SETCONFIGREQUEST,
    output_type=_SETCONFIGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetConfigMulti',
    full_name='rs485.RS485.SetConfigMulti',
    index=5,
    containing_service=None,
    input_type=_SETCONFIGMULTIREQUEST,
    output_type=_SETCONFIGMULTIRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_RS485)

DESCRIPTOR.services_by_name['RS485'] = _RS485

# @@protoc_insertion_point(module_scope)
